#[non_exhaustive]pub enum TracingInitError {
Filter(ParseError),
Install(TryInitError),
}Expand description
Why TracingSetup::init could not start the logging.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Filter(ParseError)
The log filter, built from the base level, RUST_LOG and the extra
directives, has a directive that does not parse.
Install(TryInitError)
A global tracing subscriber, or a log logger, is already installed.